# rexxar-web

Rexxar 是一个针对移动端的混合开发框架。现在支持 Android 和 iOS 平台。`rexxar-web` 是 Rexxar 的 Web 端实现，提供配合 Rexxar Container 运行的基础工具。

想要运行一个例子了解 Rexxar 的工作流程，直接查看简单的 [example](/example)。如果要在 iOS/Android Container 查看，请至 [rexxar-ios](https://www.github.com/douban/rexxar-ios) 或 [rexxar-android](https://www.github.com/douban/rexxar-android)。

## Rexxar 简介

关于 Rexxar 的整体介绍，可以查看文档：[Rexxar 简介](https://www.github.com/douban/rexxar-ios/docs/INTRODUTION.md)。

关于 Rexxar iOS，可以访问：[https://www.github.com/douban/rexxar-ios](https://www.github.com/douban/rexxar-ios)。

关于 Rexxar Android，可以访问：[https://www.github.com/douban/rexxar-android](https://www.github.com/douban/rexxar-android)。

## 安装

```bash
$ npm install rexxar-web --save
```

## 使用

### getRexxarWidget

```js
import { getWidgetBase } from 'rexxar-web';

const RexxarWidget = getWidgetBase({
  scheme: 'douban',
  host: 'rexxar-container'
});

class NavTitle extends RexxarWidget {
  constructor(title) {
    super('title');
    this.title = title;
  }
  show() {
    super.call({ title: this.title });
  }
}
let title = new NavTitle('My Title');
title.show();
```

#### getRexxarWidget(config)

传入 Widget 协议的相关配置，返回 RexxarWidget 基类，推荐使用继承的方式编写自己的业务组件。

##### `config.scheme`

Type: `String`

##### `config.host`

Type: `String`


### rexxarFetch

```js
import { rexxarFetch } from 'rexxar-web';

rexxarFetch('/request')
  .then(response => response.json())
  .then(data =>
    console.log('request succeeded with JSON response', data)
  )
  .catch(error =>
    console.log('request failed', error)
  )
```

#### rexxarFetch(input[, init])

rexxarFetch 是对 [window.fetch](https://fetch.spec.whatwg.org/) 的包装，提供与 [fetch](https://github.com/github/fetch) 一样的接口和用法。值得注意的是，在 Android Container 中使用 POST 会有所限制，只允许 `content-type` 为 `application/x-www-form-urlencoded` 的请求。

## 开发与部署

关于如何开发一个 Rexxar 页面，并进行调试，部署集成，请查看 [example](/example) 目录。
